( cd usr/X11R6/share/Blackbox/nls ; rm -rf POSIX )
( cd usr/X11R6/share/Blackbox/nls ; ln -sf C POSIX )
( cd usr/X11R6/share/Blackbox/nls ; rm -rf US_ASCII )
( cd usr/X11R6/share/Blackbox/nls ; ln -sf C US_ASCII )
( cd usr/X11R6/share/Blackbox/nls ; rm -rf en )
( cd usr/X11R6/share/Blackbox/nls ; ln -sf C en )
( cd usr/X11R6/share/Blackbox/nls ; rm -rf en_US )
( cd usr/X11R6/share/Blackbox/nls ; ln -sf C en_US )
( cd usr/X11R6/share/Blackbox/nls ; rm -rf es )
( cd usr/X11R6/share/Blackbox/nls ; ln -sf es_ES es )
( cd usr/X11R6/share/Blackbox/nls ; rm -rf fr )
( cd usr/X11R6/share/Blackbox/nls ; ln -sf fr_FR fr )
